@@ -8,7 +8,7 @@ use Config;
 use Linux::NFS::BigDir::Syscalls;
 
 use constant BUF_SIZE     => 4096;
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 =pod
 
@@ -24,22 +24,28 @@ Linux::NFS::BigDir - use Linux getdents syscall to read large directories over N
 
 =head1 DESCRIPTION
 
-This module was created to solve a very specific problem: you have a directory over NFS, mounted by
-a Linux OS, and that directory has a very large number of items (files, directories, etc). The number of entries
-is so large that you have trouble to list the contents with C<readdir> or even C<ls> from the shell. In extreme
-cases, the operation just "hangs" and will provide a feedback hours later.
+This module was created to solve a very specific problem: you have a directory
+over NFS, mounted by a Linux OS, and that directory has a very large number of
+items (files, directories, etc). The number of entries is so large that you
+have trouble to list the contents with C<readdir> or even C<ls> from the shell.
+In extreme cases, the operation just "hangs" and will provide a feedback hours
+later.
 
-I observed this behavior only with NFS version 3 (and wasn't able to simulate it with local EXT3/EXT4): you might find in different situations, 
-but in that case it migh be a wrong configuration regarding the filesystem. Ask your administrator first.
+I observed this behavior only with NFS version 3 (and wasn't able to simulate
+it with local EXT3/EXT4): you might find in different situations, but in that
+case it migh be a wrong configuration regarding the filesystem. Ask your
+administrator first.
 
-If you can't fix (or get fixed) the problem, then you might want to try to use this module. It will use the C<getdents>
-syscall from Linux. You can check the documentation about this syscall with C<man getdents> in a shell.
+If you can't fix (or get fixed) the problem, then you might want to try to use
+this module. It will use the C<getdents> syscall from Linux. You can check the
+documentation about this syscall with C<man getdents> in a shell.
 
-In short, this syscall will return a data structure, but you probably will want to use only the name of each entry in the directory.
+In short, this syscall will return a data structure, but you probably will want
+to use only the name of each entry in the directory.
 
 How can this be useful? Here are some directions:
 
-=over 
+=over
 
 =item 1.
 
@@ -47,20 +53,26 @@ You want to remove all directory content.
 
 =item 2.
 
-You want to remove files from the directory with a pattern in their filename (using regular expressions, for example).
+You want to remove files from the directory with a pattern in their filename
+(using regular expressions, for example).
 
 =item 3.
 
-You want to select specific files by their filenames and then test something else (like atime).
+You want to select specific files by their filenames and then test something
+else (like atime).
 
 =back
 
-These are examples, but it should cover the vast majority of what you want to do. C<getdents> syscall will be more effective because
-it will not call C<stat> of each of those files before returning the information to you. That means, you will have the opportunity to filter
-whatever you need and then call C<stat> if you really need.
+These are examples, but it should cover the vast majority of what you want to
+do. C<getdents> syscall will be more effective because it will not call
+C<stat> of each of those files before returning the information to you. That
+means, you will have the opportunity to filter whatever you need and then call
+C<stat> if you really need.
 
-I came up at C<getdents> after researching about "how to remove million of files". After a while I reached an C program example that uses C<getdents>
-to print the filenames under the directory. By using it, I was able to cleanup directories with thousands (or even millions) of files in a couple of minutes, 
+I came up at C<getdents> after researching about "how to remove million of
+files". After a while I reached an C program example that uses C<getdents> to
+print the filenames under the directory. By using it, I was able to cleanup
+directories with thousands (or even millions) of files in a couple of minutes,
 instead of many hours.
 
 This module is a Perl implementation of that.
@@ -77,11 +89,14 @@ our @EXPORT_OK = qw(getdents getdents_safe);
 
 Expects the complete path to the directory as a parameter.
 
-Returns an array reference with all files inside that directory but the 'dot' files.
+Returns an array reference with all files inside that directory but without the
+'dot' files.
 
-Meanwhile simple (and probably faster), you should be careful regarding memory restrictions when using this functions.
+Meanwhile simple (and probably faster), you should be careful regarding memory
+restrictions when using this functions.
 
-If you have too many files, you program may try to allocate too much memory, with all the undesired effects. See C<getdents_safe>.
+If you have too many files, you program may try to allocate too much memory,
+with all the undesired effects. See C<getdents_safe>.
 
 =cut
 
@@ -118,8 +133,8 @@ sub getdents {
 
 =head2 getdents_safe
 
-"Safe" version of C<getdents> because it will write each entry read to a text file instead of storing
-all the entries on memory.
+"Safe" version of C<getdents> because it will write each entry read to a text
+file instead of storing all the entries on memory.
 
 Expects as parameters:
 
@@ -131,12 +146,14 @@ The complete path to the directory to be read.
 
 =item *
 
-The complete path to the file that will be used to print each entry, one per line. As convenience, all filenames will be
-prepended with the complete path to the directory given as parameter.
+The complete path to the file that will be used to print each entry, one per
+line. As convenience, all filenames will be prepended with the complete path
+to the directory given as parameter.
 
 =back
 
-The filename given will be created. If it already exists, this function will C<die>.
+The filename given will be created. If it already exists, this function will
+C<die>.
 
 This function returns the number of files read from the given directory.
 
@@ -200,8 +217,9 @@ sub getdents_safe {
 
 =head1 TO DO
 
-Create C versions of C<getdents> and C<getdents_safe> with L<Inline::C> to see if they get close to C<readdir>
-speed when running over a B<local> file system (currently they are slower).
+Create C versions of C<getdents> and C<getdents_safe> with L<Inline::C> to see
+if they get close to C<readdir> speed when running over a B<local> file system
+(currently they are slower).
 
 =head1 SEE ALSO
 
@@ -231,7 +249,8 @@ Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
+This software is copyright (c) 2016 of Alceu Rodrigues de Freitas Junior,
+E<lt>glasswalk3r@yahoo.com.brE<gt>.
 
 This file is part of Linux-NFS-BigDir distribution.
 
